@@ -4,7 +4,8 @@ import SparseArrays
 import RecursiveArrayTools
 
 function Base.copyto!(
-        dest::SparseArrays.AbstractCompressedVector, A::RecursiveArrayTools.ArrayPartition)
+        dest::SparseArrays.AbstractCompressedVector, A::RecursiveArrayTools.ArrayPartition
+    )
     @assert length(dest) == length(A)
     cur = 1
     @inbounds for i in 1:length(A.x)
@@ -15,7 +16,7 @@ function Base.copyto!(
         end
         cur += length(A.x[i])
     end
-    dest
+    return dest
 end
 
 # Fix for issue #486: Define issparse for AbstractVectorOfArray
